==> vxl_1.13.0.orig.tar.gz: vxl-1.13.0/contrib/mul/mbl/tests/test_include.cxx <==
#include <mbl/mbl_add_all_loaders.h>
#include <mbl/mbl_ar_process.h>
#include <mbl/mbl_chord.h>
#include <mbl/mbl_chord_3d.h>
#include <mbl/mbl_clamped_plate_spline_2d.h>
#include <mbl/mbl_cloneable_ptr.h>
#include <mbl/mbl_cloneables_factory.h>
#include <mbl/mbl_cluster_tree.h>
#include <mbl/mbl_clusters.h>
#include <mbl/mbl_combination.h>
#include <mbl/mbl_correspond_points.h>
#include <mbl/mbl_data_array_ptr_wrapper.h>
#include <mbl/mbl_data_array_wrapper.h>
#include <mbl/mbl_data_collector_base.h>
#include <mbl/mbl_data_collector.h>
#include <mbl/mbl_data_collector_list.h>
#include <mbl/mbl_data_wrapper.h>
#include <mbl/mbl_data_wrapper_mixer.h>
#include <mbl/mbl_draw_line.h>
#include <mbl/mbl_dyn_prog.h>
#include <mbl/mbl_exception.h>
#include <mbl/mbl_file_data_collector.h>
#include <mbl/mbl_file_data_wrapper.h>
#include <mbl/mbl_gamma.h>
#include <mbl/mbl_histogram.h>
#include <mbl/mbl_index_sort.h>
#include <mbl/mbl_jarque_bera.h>
#include <mbl/mbl_k_means.h>
#include <mbl/mbl_lda.h>
#include <mbl/mbl_linear_interpolator.h>
#include <mbl/mbl_log.h>
#include <mbl/mbl_lru_cache.h>
#include <mbl/mbl_matrix_products.h>
#include <mbl/mbl_matxvec.h>
#include <mbl/mbl_minimum_spanning_tree.h>
#include <mbl/mbl_mod_gram_schmidt.h>
#include <mbl/mbl_parse_block.h>
#include <mbl/mbl_parse_int_list.h>
#include <mbl/mbl_parse_sequence.h>
#include <mbl/mbl_parse_tuple.h>
#include <mbl/mbl_print.h>
#include <mbl/mbl_priority_bounded_queue.h>
#include <mbl/mbl_progress.h>
#include <mbl/mbl_progress_callback.h>
#include <mbl/mbl_progress_composite.h>
#include <mbl/mbl_progress_hierarchy.h>
#include <mbl/mbl_progress_null.h>
#include <mbl/mbl_progress_text.h>
#include <mbl/mbl_progress_time.h>
#include <mbl/mbl_random_n_from_m.h>
#include <mbl/mbl_rbf_network.h>
#include <mbl/mbl_read_double.h>
#include <mbl/mbl_read_int.h>
#include <mbl/mbl_read_multi_props.h>
#include <mbl/mbl_read_props.h>
#include <mbl/mbl_read_str.h>
#include <mbl/mbl_read_yes.h>
#include <mbl/mbl_rvm_regression_builder.h>
#include <mbl/mbl_sample_stats_1d.h>
#include <mbl/mbl_screen_counter.h>
#include <mbl/mbl_selected_data_wrapper.h>
#include <mbl/mbl_select_n_from_m.h>
#include <mbl/mbl_stats_1d.h>
#include <mbl/mbl_stats_nd.h>
#include <mbl/mbl_stepwise_regression.h>
#include <mbl/mbl_stl.h>
#include <mbl/mbl_stl_pred.h>
#include <mbl/mbl_stochastic_data_collector.h>
#include <mbl/mbl_sum_1d.h>
#include <mbl/mbl_table.h>
#include <mbl/mbl_test.h>
#include <mbl/mbl_thin_plate_spline_2d.h>
#include <mbl/mbl_thin_plate_spline_3d.h>
#include <mbl/mbl_thin_plate_spline_weights_3d.h>
#include <mbl/mbl_vector_distance.h>
#include <mbl/mbl_wt_histogram.h>
#include <mbl/mbl_save_text_file.h>
#include <mbl/mbl_load_text_file.h>

int main() { return 0; }

==> vxl_1.14.0.orig.tar.gz: vxl-1.14.0/contrib/mul/mbl/tests/test_include.cxx <==
#include <mbl/mbl_add_all_loaders.h>
#include <mbl/mbl_ar_process.h>
#include <mbl/mbl_chord.h>
#include <mbl/mbl_chord_3d.h>
#include <mbl/mbl_clamped_plate_spline_2d.h>
#include <mbl/mbl_cloneable_ptr.h>
#include <mbl/mbl_cloneables_factory.h>
#include <mbl/mbl_cluster_tree.h>
#include <mbl/mbl_clusters.h>
#include <mbl/mbl_combination.h>
#include <mbl/mbl_correspond_points.h>
#include <mbl/mbl_data_array_ptr_wrapper.h>
#include <mbl/mbl_data_array_wrapper.h>
#include <mbl/mbl_data_collector_base.h>
#include <mbl/mbl_data_collector.h>
#include <mbl/mbl_data_collector_list.h>
#include <mbl/mbl_data_wrapper.h>
#include <mbl/mbl_data_wrapper_mixer.h>
#include <mbl/mbl_draw_line.h>
#include <mbl/mbl_dyn_prog.h>
#include <mbl/mbl_exception.h>
#include <mbl/mbl_file_data_collector.h>
#include <mbl/mbl_file_data_wrapper.h>
#include <mbl/mbl_gamma.h>
#include <mbl/mbl_histogram.h>
#include <mbl/mbl_index_sort.h>
#include <mbl/mbl_jarque_bera.h>
#include <mbl/mbl_k_means.h>
#include <mbl/mbl_lda.h>
#include <mbl/mbl_linear_interpolator.h>
#include <mbl/mbl_load_text_file.h>
#include <mbl/mbl_log.h>
#include <mbl/mbl_lru_cache.h>
#include <mbl/mbl_mask.h>
#include <mbl/mbl_matrix_products.h>
#include <mbl/mbl_matxvec.h>
#include <mbl/mbl_minimum_spanning_tree.h>
#include <mbl/mbl_mod_gram_schmidt.h>
#include <mbl/mbl_parse_block.h>
#include <mbl/mbl_parse_colon_pairs_list.h>
#include <mbl/mbl_parse_int_list.h>
#include <mbl/mbl_parse_sequence.h>
#include <mbl/mbl_parse_string_list.h>
#include <mbl/mbl_parse_tuple.h>
#include <mbl/mbl_print.h>
#include <mbl/mbl_priority_bounded_queue.h>
#include <mbl/mbl_progress.h>
#include <mbl/mbl_progress_callback.h>
#include <mbl/mbl_progress_composite.h>
#include <mbl/mbl_progress_hierarchy.h>
#include <mbl/mbl_progress_null.h>
#include <mbl/mbl_progress_text.h>
#include <mbl/mbl_progress_time.h>
#include <mbl/mbl_random_n_from_m.h>
#include <mbl/mbl_rbf_network.h>
#include <mbl/mbl_read_double.h>
#include <mbl/mbl_read_int.h>
#include <mbl/mbl_read_multi_props.h>
#include <mbl/mbl_read_props.h>
#include <mbl/mbl_read_str.h>
#include <mbl/mbl_read_yes.h>
#include <mbl/mbl_rvm_regression_builder.h>
#include <mbl/mbl_sample_stats_1d.h>
#include <mbl/mbl_save_text_file.h>
#include <mbl/mbl_screen_counter.h>
#include <mbl/mbl_selected_data_wrapper.h>
#include <mbl/mbl_select_n_from_m.h>
#include <mbl/mbl_stats_1d.h>
#include <mbl/mbl_stats_nd.h>
#include <mbl/mbl_stepwise_regression.h>
#include <mbl/mbl_stl.h>
#include <mbl/mbl_stl_pred.h>
#include <mbl/mbl_stochastic_data_collector.h>
#include <mbl/mbl_sum_1d.h>
#include <mbl/mbl_table.h>
#include <mbl/mbl_test.h>
#include <mbl/mbl_thin_plate_spline_2d.h>
#include <mbl/mbl_thin_plate_spline_3d.h>
#include <mbl/mbl_thin_plate_spline_weights_3d.h>
#include <mbl/mbl_vector_distance.h>
#include <mbl/mbl_wt_histogram.h>

int main() { return 0; }
